@@ -7,7 +7,7 @@ require 'homesick/cli'
 
 # Homesick's top-level module
 module Homesick
-  GITHUB_NAME_REPO_PATTERN = /\A([A-Za-z0-9_-]+\/[A-Za-z0-9_-]+)\Z/
+  GITHUB_NAME_REPO_PATTERN = %r{\A([A-Za-z0-9_-]+/[A-Za-z0-9_-]+)\Z}
   SUBDIR_FILENAME = '.homesick_subdir'
 
   DEFAULT_CASTLE_NAME = 'dotfiles'
