@@ -42,7 +42,7 @@ module Homesick
       end
 
       def ln_s(source, destination)
-        source = Pathname.new(source)
+        source = Pathname.new(source).realpath        
         destination = Pathname.new(destination)
         FileUtils.mkdir_p destination.dirname
 
@@ -63,16 +63,14 @@ module Homesick
         case action
         when :identical
           say_status :identical, destination.expand_path, :blue
-        when :symlink_conflict
-          say_status :conflict,
-                     "#{destination} exists and points to #{destination.readlink}",
-                     :red
-
-          FileUtils.rm destination
-          FileUtils.ln_s source, destination, force: true unless options[:pretend]
-        when :conflict
-          say_status :conflict, "#{destination} exists", :red
-
+        when :symlink_conflict, :conflict
+          if action == :conflict
+            say_status :conflict, "#{destination} exists", :red
+          else
+            say_status :conflict,
+                      "#{destination} exists and points to #{destination.readlink}",
+                      :red
+          end
           if collision_accepted?(destination, source)
             FileUtils.rm_r destination, force: true unless options[:pretend]
             FileUtils.ln_s source, destination, force: true unless options[:pretend]
